@@ -1,7 +1,8 @@
 /*****************************************************************************\
- *  $Id: genders.c,v 1.136 2005/05/07 17:24:31 achu Exp $
+ *  $Id: genders.c,v 1.141 2008/03/28 16:56:28 chu11 Exp $
  *****************************************************************************
- *  Copyright (C) 2001-2003 The Regents of the University of California.
+ *  Copyright (C) 2007-2008 Lawrence Livermore National Security, LLC.
+ *  Copyright (C) 2001-2007 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
  *  Written by Jim Garlick <garlick@llnl.gov> and Albert Chu <chu11@llnl.gov>.
  *  UCRL-CODE-2003-004.
@@ -20,8 +21,7 @@
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with Genders; if not, write to the Free Software Foundation, Inc.,
- *  59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
+ *  with Genders.  If not, see <http://www.gnu.org/licenses/>.
 \*****************************************************************************/
 
 #if HAVE_CONFIG_H
@@ -600,6 +600,13 @@ genders_getnodes(genders_t handle, char *nodes[], int len,
       /* Case B: atleast the attr was input, so use attr_index */
       List l;
       
+      if (!handle->attr_index)
+        {
+	  /* No attributes, so no nodes have this attr */
+	  handle->errnum = GENDERS_ERR_SUCCESS;
+	  return 0;
+        }
+
       if (!(l = hash_find(handle->attr_index, attr))) 
 	{
 	  /* No nodes have this attr */
@@ -663,6 +670,12 @@ genders_getattr(genders_t handle,
   if (!node)
     node = handle->nodename;
   
+  if (!handle->node_index)
+    {
+      handle->errnum = GENDERS_ERR_NOTFOUND;
+      return -1;
+    }
+
   if (!(n = hash_find(handle->node_index, node))) 
     {
       handle->errnum = GENDERS_ERR_NOTFOUND;
@@ -760,6 +773,12 @@ genders_testattr(genders_t handle,
   if (!node)
     node = handle->nodename;
 
+  if (!handle->node_index)
+    {
+      handle->errnum = GENDERS_ERR_NOTFOUND;
+      return -1;
+    }
+
   if (!(n = hash_find(handle->node_index, node))) 
     {
       handle->errnum = GENDERS_ERR_NOTFOUND;
@@ -815,6 +834,12 @@ genders_testattrval(genders_t handle,
   if (!node)
     node = handle->nodename;
 
+  if (!handle->node_index)
+    {
+      handle->errnum = GENDERS_ERR_NOTFOUND;
+      return -1;
+    }
+
   if (!(n = hash_find(handle->node_index, node))) 
     {
       handle->errnum = GENDERS_ERR_NOTFOUND;
@@ -839,6 +864,13 @@ genders_isnode(genders_t handle, const char *node)
   if (!node)
     node = handle->nodename;
 
+  if (!handle->node_index)
+    {
+      /* No nodes, so node not found */
+      handle->errnum = GENDERS_ERR_SUCCESS;
+      return 0;
+    }
+
   n = hash_find(handle->node_index, node);
   handle->errnum = GENDERS_ERR_SUCCESS;
   return ((n) ? 1 : 0);
@@ -858,6 +890,13 @@ genders_isattr(genders_t handle, const char *attr)
       return -1;
     }
 
+  if (!handle->attr_index)
+    {
+      /* No attributes, so attr not found */
+      handle->errnum = GENDERS_ERR_SUCCESS;
+      return 0;
+    }
+
   ptr = hash_find(handle->attr_index, attr);
   handle->errnum = GENDERS_ERR_SUCCESS;
   return ((ptr) ? 1 : 0);
@@ -883,9 +922,7 @@ genders_isattrval(genders_t handle, const char *attr, const char *val)
   if (handle->attrval_index 
       && !strcmp(handle->attrval_index_attr, attr)) 
     {
-      List l;
-      
-      if (!(l = hash_find(handle->attrval_index, val)))
+      if (!hash_find(handle->attrval_index, val))
 	rv = 0;
       else
 	rv = 1;
@@ -955,6 +992,13 @@ genders_index_attrvals(genders_t handle, const char *attr)
       return 0;
     }
 
+  /* Nothing to index if there are no nodes */
+  if (!handle->numnodes)
+    {
+      handle->errnum = GENDERS_ERR_SUCCESS;
+      return 0;
+    }
+
   /* Max possible hash size is number of nodes, so pick upper boundary */
   __hash_create(attrval_index, 
                 handle->numnodes, 
