@@ -1,7 +1,8 @@
 /*****************************************************************************\
- *  $Id: genders_test_database.c,v 1.2 2004/12/29 23:36:05 achu Exp $
+ *  $Id: genders_test_database.c,v 1.6 2008/03/28 16:56:37 chu11 Exp $
  *****************************************************************************
- *  Copyright (C) 2001-2003 The Regents of the University of California.
+ *  Copyright (C) 2007-2008 Lawrence Livermore National Security, LLC.
+ *  Copyright (C) 2001-2007 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
  *  Written by Jim Garlick <garlick@llnl.gov> and Albert Chu <chu11@llnl.gov>.
  *  UCRL-CODE-2003-004.
@@ -20,8 +21,7 @@
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with Genders; if not, write to the Free Software Foundation, Inc.,
- *  59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
+ *  with Genders.  If not, see <http://www.gnu.org/licenses/>.
 \*****************************************************************************/
 
 #include <stdio.h>
@@ -31,8 +31,12 @@
 
 genders_parse_error_database_t genders_parse_error_databases[] = 
   {
+#if 0
+    /* No longer a parse error */
     {"testdatabases/genders.parse_error_empty_file", 1},
+    /* No longer a parse error */
     {"testdatabases/genders.parse_error_comments_only", 1},
+#endif
     {"testdatabases/genders.parse_error_hostname_not_shortened", 1},
     {"testdatabases/genders.parse_error_hostname_not_shortened_comma", 1},
     {"testdatabases/genders.parse_error_hostname_not_shortened_hostrange", 1},
@@ -897,6 +901,49 @@ genders_database_t genders_database_test_3 =
     &genders_database_data_test_3,
   };
 
+genders_database_data_t genders_database_data_empty = 
+  {
+    NULL,
+    NULL,
+    NULL,
+    NULL,
+    0,
+    0,
+    0,
+    0,
+    0,
+    0,
+    {NULL},
+    0,
+    {NULL},
+    0,
+    {NULL},
+    0,
+    {
+      {
+	{NULL},
+	{NULL},
+	{NULL}
+      }
+    },
+    0,
+    {
+      {
+	NULL,
+	NULL,
+	{NULL},
+	0,
+      },
+    },
+    0,
+  };
+
+genders_database_t genders_database_empty =
+  {
+    "testdatabases/genders.empty_file",
+    &genders_database_data_empty,
+  };
+
 genders_database_data_t genders_database_data_nodes_only_one = 
   {
     "node1",
@@ -1407,6 +1454,7 @@ genders_database_t *genders_functionality_databases[] =
     &genders_database_test_2_comma,
     &genders_database_test_2_hostrange,
     &genders_database_test_3,
+    &genders_database_empty,
     &genders_database_nodes_only_one,
     &genders_database_nodes_only_many,
     &genders_database_nodes_and_attrs_only,
